--[[
	TitanDarkmoonTicket: A simple display of your current Darkmoon Prize Ticket value.
	Author: Canettieri
--]]

-- Default language (enUS)
local L = {}
L["buttonLabel"] = "Tickets: "
L["tooltipTitle"] = "Darkmoon Prize Ticket"
L["tooltipDescription"] = "Awarded for winning games or doing\rfavors at the Darkmoon Faire."
L["tooltipCountLabel"] = "Total: "
local ACE = LibStub("AceLocale-3.0"):GetLocale("Titan", true)

local version = "1.6"
local ID = "DT"
local elap, currencyCount = 0, 0.0

-- Main button frame and addon base
local f = CreateFrame("Button", "TitanPanelDTButton", CreateFrame("Frame", nil, UIParent), "TitanPanelComboTemplate")
f:SetFrameStrata("FULLSCREEN")
f:SetScript("OnEvent", function(this, event, ...) this[event](this, ...) end)
f:RegisterEvent("ADDON_LOADED")

function f:ADDON_LOADED(a1)
	if a1 ~= "TitanCurrenciesMulti" then
	return 
	end
	self:UnregisterEvent("ADDON_LOADED")
	self.ADDON_LOADED = nil
	
	-- Brazilian Portuguese
	if GetLocale() == "ptBR" then
		L["buttonLabel"] = "Cupons: "
		L["tooltipTitle"] = "Cupom Premiado de Negraluna"
		L["tooltipDescription"] = "Concedidos a quem ganhar jogos ou\rrealizar favores na Feira de Negraluna."
		L["tooltipCountLabel"] = "Total: "
	end	

	local name, isHeader, isExpanded, isUnused, isWatched, count, icon, hasWeeklyLimit, currentWeeklyAmount, unknown
	local i = 0
	local CurrencyIndex = 0
	local myicon = "Interface\\Icons\\inv_misc_ticket_darkmoon_01.blp"
	local mycheck = "Interface\\Icons\\inv_misc_ticket_darkmoon_01"

	self.registry = {
		id = ID,
		menuText = "Titan|cFF007edd "..L["tooltipTitle"].."|r",
		buttonTextFunction = "TitanPanelDTButton_GetButtonText",
		tooltipTitle = L["tooltipTitle"],
		tooltipTextFunction = "TitanPanelDTButton_GetTooltipText",
		frequency = 2,
		icon = myicon,
		iconWidth = 16,
		category = "Information",
		version = version,
		savedVariables = {
			ShowIcon = 1,
			DisplayOnRightSide = false,
			ShowLabelText = false,
		},
	}
	
	self:SetScript("OnUpdate", function(this, a1)
		elap = elap + a1
		if elap < 1 then return end

		for i = 1, GetCurrencyListSize(), 1 do
			
			name, isHeader, isExpanded, isUnused, isWatched, count, icon, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(i)
			if string.lower(tostring(icon)) == string.lower(mycheck) then
				CurrencyIndex = i
			end
			
		end
		
		name, isHeader, isExpanded, isUnused, isWatched, count, icon, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(CurrencyIndex)

		currencyCount = count
		
		TitanPanelButton_UpdateButton(ID)
		elap = 0
	end)
		
end

----------------------------------------------
function TitanPanelDTButton_GetButtonText()
----------------------------------------------
	local currencyCountText
	if not currencyCount then
		currencyCountText = TitanUtils_GetHighlightText("0")
	else	
		currencyCountText = TitanUtils_GetHighlightText(string.format("%.0f", currencyCount) .."")
	end
	return L["buttonLabel"], currencyCountText
end

-----------------------------------------------
function TitanPanelDTButton_GetTooltipText() --Thanks to my friend, Eliote
-----------------------------------------------
	local texto_tooltip = TitanUtils_GetHighlightText(currencyCount)
	
	if not texto_tooltip then
		texto_tooltip = TitanUtils_GetHighlightText("0")
	end
	
	return L["tooltipDescription"].."\r\r"..L["tooltipCountLabel"]..texto_tooltip
end

----------------------------------------------------
function TitanPanelRightClickMenu_PrepareDTMenu()
----------------------------------------------------
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[ID].menuText)
	TitanPanelRightClickMenu_AddToggleIcon(ID)
	TitanPanelRightClickMenu_AddToggleLabelText(ID)
	
info = {};
	info.text = ACE["TITAN_CLOCK_MENU_DISPLAY_ON_RIGHT_SIDE"];
	info.func = TitanPanelDTButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	TitanPanelRightClickMenu_AddSpacer();
	TitanPanelRightClickMenu_AddCommand(ACE["TITAN_PANEL_MENU_HIDE"], ID, TITAN_PANEL_MENU_FUNC_HIDE);
end

-----------------------------------------------
function TitanPanelDTButton_ToggleRightSideDisplay() -- Right Side display
-----------------------------------------------
	TitanToggleVar(ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end