--[[
	TitanGarrisonRes: A simple display of your current Garrison Resources value.
	Author: Canettieri
--]]

-- Default language (enUS)
local L = {}
L["buttonLabel"] = "Resources: "
L["tooltipTitle"] = "Garrison Resources"
L["tooltipDescription"] = "Earn resources to build-up and\rexpand your garrison."
L["tooltipCountLabel"] = "Total Maximum: "
L["maximum"] = "Max!"
local ACE = LibStub("AceLocale-3.0"):GetLocale("Titan", true)

local version = "1.6"
local ID = "TITAN_GRCTT"
local elap, currencyCount = 0, 0.0
local currencyMaximum

-- Main button frame and addon base
local f = CreateFrame("Button", "TitanPanelTITAN_GRCTTButton", CreateFrame("Frame", nil, UIParent), "TitanPanelComboTemplate")
f:SetFrameStrata("FULLSCREEN")
f:SetScript("OnEvent", function(this, event, ...) this[event](this, ...) end)
f:RegisterEvent("ADDON_LOADED")

function f:ADDON_LOADED(a1)
	if a1 ~= "TitanCurrenciesMulti" then
	return 
	end
	self:UnregisterEvent("ADDON_LOADED")
	self.ADDON_LOADED = nil
	
	-- Brazilian Portuguese
	if GetLocale() == "ptBR" then
		L["buttonLabel"] = "Recursos: "
		L["tooltipTitle"] = "Recursos da Guarnição"
		L["tooltipDescription"] = "Ganhe recursos para expandir ou\rconstruir sua Guarnição."
		L["tooltipCountLabel"] = "Máximo total: "
		L["maximum"] = "Máx!"
	end

	local name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown
	local i = 0
	local CurrencyIndex = 0
	local myicon = "Interface\\Icons\\inv_garrison_resource.blp"
	local mycheck = "Interface\\Icons\\Inv_Garrison_Resource"

	self.registry = {
		id = ID,
		menuText = "Titan|cFF007edd "..L["tooltipTitle"].."|r",
		buttonTextFunction = "TitanPanelTITAN_GRCTTButton_GetButtonText",
		tooltipTitle = L["tooltipTitle"],
		tooltipTextFunction = "TitanPanelTITAN_GRCTTButton_GetTooltipText",
		frequency = 2,
		icon = myicon,
		iconWidth = 16,
		category = "Information",
		version = version,
		savedVariables = {
			ShowIcon = 1,
			DisplayOnRightSide = false,
			ShowLabelText = false,
		},
	}
	
	self:SetScript("OnUpdate", function(this, a1)
		elap = elap + a1
		if elap < 1 then return end

		for i = 1, GetCurrencyListSize(), 1 do
			
			name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(i)
			if string.lower(tostring(icon)) == string.lower(mycheck) then
				CurrencyIndex = i
			end
			
		end
		
		name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(CurrencyIndex)

		 currencyCount = count
		currencyMaximum = maximum
		
		TitanPanelButton_UpdateButton(ID)
		elap = 0
	end)
		
end

----------------------------------------------
function TitanPanelTITAN_GRCTTButton_GetButtonText()
----------------------------------------------
	local currencyCountText
	if not currencyCount then
		currencyCountText = TitanUtils_GetHighlightText("0")
	elseif currencyCount > 2999 and currencyCount < 5000 then
		currencyCountText = "|cFF69FF69"..currencyCount
	elseif currencyCount > 4999 and currencyCount < 7000 then
		currencyCountText = "|cFFf6ed12"..currencyCount
	elseif currencyCount > 6999 and currencyCount < 9000 then
		currencyCountText = "|cFFf69112"..currencyCount
	elseif currencyCount > 8999 and currencyCount < 10000 then
		currencyCountText = "|cFFFF2e2e"..currencyCount
	elseif currencyCount == currencyMaximum then
		currencyCountText = "|cFFFF2e2e"..L["maximum"]
	else
		currencyCountText = TitanUtils_GetHighlightText(string.format("%.0f", currencyCount) .."")
	end
	return L["buttonLabel"], currencyCountText
end

-----------------------------------------------
function TitanPanelTITAN_GRCTTButton_GetTooltipText() --Thanks to my friend, Eliote
-----------------------------------------------
	local valorAtual = TitanUtils_GetHighlightText(Util_StringComDefault(currencyCount, "0"))
	local valorMaximo = TitanUtils_GetHighlightText(Util_StringComDefault(currencyMaximum, "0"))
	
	return L["tooltipDescription"].."\r\r"..L["tooltipCountLabel"]..valorAtual.." / "..valorMaximo
end

----------------------------------------------------
function TitanPanelRightClickMenu_PrepareTITAN_GRCTTMenu()
----------------------------------------------------
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[ID].menuText)
	TitanPanelRightClickMenu_AddToggleIcon(ID)
	TitanPanelRightClickMenu_AddToggleLabelText(ID)
	
info = {};
	info.text = ACE["TITAN_CLOCK_MENU_DISPLAY_ON_RIGHT_SIDE"];
	info.func = TitanPanelTITAN_GRCTTButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	TitanPanelRightClickMenu_AddSpacer();
	TitanPanelRightClickMenu_AddCommand(ACE["TITAN_PANEL_MENU_HIDE"], ID, TITAN_PANEL_MENU_FUNC_HIDE);
end

-----------------------------------------------
function TitanPanelTITAN_GRCTTButton_ToggleRightSideDisplay() -- Right side display
-----------------------------------------------
	TitanToggleVar(ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end

----------------------------------------------------
function Util_StringComDefault(v,d)
----------------------------------------------------
	if not v then
		return d
	end
	
	return v
end