--[[
	TitanHonor: A simple display of your current Honor Points.
	Author: Canettieri
--]]

-- Default language (enUS)
local L = {}
L["buttonLabel"] = "Honor: "
L["tooltipTitle"] = "Honor Points"
L["tooltipDescription"] = "Used to purchase PvP armor\rand weapons."
L["tooltipCountLabel"] = "Total Maximum: "
local ACE = LibStub("AceLocale-3.0"):GetLocale("Titan", true)

local version = "1.6"
local ID = "TITAN_HRPTM"
local elap, currencyCount = 0, 0.0
local currencyMaximum

-- Main button frame and addon base
local f = CreateFrame("Button", "TitanPanelTITAN_HRPTMButton", CreateFrame("Frame", nil, UIParent), "TitanPanelComboTemplate")
f:SetFrameStrata("FULLSCREEN")
f:SetScript("OnEvent", function(this, event, ...) this[event](this, ...) end)
f:RegisterEvent("ADDON_LOADED")

function f:ADDON_LOADED(a1)
	if a1 ~= "TitanCurrenciesMulti" then
	return 
	end
	self:UnregisterEvent("ADDON_LOADED")
	self.ADDON_LOADED = nil
	
	-- Brazilian Portuguese
	if GetLocale() == "ptBR" then
		L["buttonLabel"] = "Honra: "
		L["tooltipTitle"] = "Pontos de Honra"
		L["tooltipDescription"] = "Usado para adquirir armas e\rarmaduras de JxJ."
		L["tooltipCountLabel"] = "Máximo total: "
	end

	local name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown
	local i = 0
	local CurrencyIndex = 0
		if UnitFactionGroup("Player") == "Alliance" then
		myicon = "Interface\\Icons\\pvpcurrency-honor-alliance.blp"
		mycheck ="Interface\\Icons\\pvpcurrency-honor-alliance"
	else
		myicon = "Interface\\Icons\\pvpcurrency-honor-horde.blp"
		mycheck = "Interface\\Icons\\pvpcurrency-honor-horde"
	end

	self.registry = {
		id = ID,
		menuText = "Titan|cFF007edd "..L["tooltipTitle"].."|r",
		buttonTextFunction = "TitanPanelTITAN_HRPTMButton_GetButtonText",
		tooltipTitle = L["tooltipTitle"],
		tooltipTextFunction = "TitanPanelTITAN_HRPTMButton_GetTooltipText",
		frequency = 2,
		icon = myicon,
		iconWidth = 16,
		category = "Information",
		version = version,
		savedVariables = {
			ShowIcon = 1,
			DisplayOnRightSide = false,
			ShowLabelText = false,
		},
	}
	
	self:SetScript("OnUpdate", function(this, a1)
		elap = elap + a1
		if elap < 1 then return end

		for i = 1, GetCurrencyListSize(), 1 do
			
			name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(i)
			if string.lower(tostring(icon)) == string.lower(mycheck) then
				CurrencyIndex = i
			end
			
		end
		
		name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(CurrencyIndex)

		currencyCount = count
		currencyMaximum = maximum/100-0.99
		
		TitanPanelButton_UpdateButton(ID)
		elap = 0
	end)
		
end

----------------------------------------------
function TitanPanelTITAN_HRPTMButton_GetButtonText()
-----------------------------------------------
	local currencyCountText
	if not currencyCount then
		currencyCountText = TitanUtils_GetHighlightText("0")
	else	
		currencyCountText = TitanUtils_GetHighlightText(string.format("%.0f", currencyCount) .."")
	end
	return L["buttonLabel"], currencyCountText
end

-----------------------------------------------
function TitanPanelTITAN_HRPTMButton_GetTooltipText() --Thanks to my friend, Eliote
-----------------------------------------------
	local valorAtual = TitanUtils_GetHighlightText(Util_StringComDefault(currencyCount, "0"))
	local valorMaximo = TitanUtils_GetHighlightText(Util_StringComDefault(currencyMaximum, "0"))
	
	return L["tooltipDescription"].."\r\r"..L["tooltipCountLabel"]..valorAtual.." / "..valorMaximo
end

----------------------------------------------------
function TitanPanelRightClickMenu_PrepareTITAN_HRPTMMenu()
----------------------------------------------------
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[ID].menuText)
	TitanPanelRightClickMenu_AddToggleIcon(ID)
	TitanPanelRightClickMenu_AddToggleLabelText(ID)
	
info = {};
	info.text = ACE["TITAN_CLOCK_MENU_DISPLAY_ON_RIGHT_SIDE"];
	info.func = TitanPanelTITAN_HRPTMButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	TitanPanelRightClickMenu_AddSpacer();
	TitanPanelRightClickMenu_AddCommand(ACE["TITAN_PANEL_MENU_HIDE"], ID, TITAN_PANEL_MENU_FUNC_HIDE);
end

-----------------------------------------------
function TitanPanelTITAN_HRPTMButton_ToggleRightSideDisplay() -- Right side display
-----------------------------------------------
	TitanToggleVar(ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end

----------------------------------------------------
function Util_StringComDefault(v,d)
----------------------------------------------------
	if not v then
		return d
	end
	
	return v
end