--[[
	TitanInevitableFate: A simple display of your current Seal of Inevitable Fate value.
	Author: Canettieri
--]]

-- Default language (enUS)
local L = {}
L["buttonLabel"] = "Inevitable: "
L["tooltipTitle"] = "Seal of Inevitable Fate "
L["tooltipDescription"] = "Twists fate to provide an opportunity for\radditional treasure in Hellfire Citadel or\rMythic Dungeons."
L["tooltipCountLabel"] = "Total Maximum: "
local ACE = LibStub("AceLocale-3.0"):GetLocale("Titan", true)

local version = "1.6"
local ID = "TITAN_SOIFTM"
local elap, currencyCount = 0, 0.0
local currencyMaximum

-- Main button frame and addon base
local f = CreateFrame("Button", "TitanPanelTITAN_SOIFTMButton", CreateFrame("Frame", nil, UIParent), "TitanPanelComboTemplate")
f:SetFrameStrata("FULLSCREEN")
f:SetScript("OnEvent", function(this, event, ...) this[event](this, ...) end)
f:RegisterEvent("ADDON_LOADED")

function f:ADDON_LOADED(a1)
	if a1 ~= "TitanCurrenciesMulti" then
	return 
	end
	self:UnregisterEvent("ADDON_LOADED")
	self.ADDON_LOADED = nil
	
	-- Brazilian Portuguese
	if GetLocale() == "ptBR" then
		L["buttonLabel"] = "Inevitável: "
		L["tooltipTitle"] = "Selo do Destino Inevitável"
		L["tooltipDescription"] = "Manipula o destino para aumentar a chance\rde encontrar tesouro extra na Cidadela Fogo\rdo Inferno ou Masmorras Míticas."
		L["tooltipCountLabel"] = "Máximo total: "
	end

	local name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown
	local i = 0
	local CurrencyIndex = 0
	local myicon = "Interface\\Icons\\achievement_battleground_templeofkotmogu_02_green.blp"
	local mycheck = "Interface\\Icons\\achievement_battleground_templeofkotmogu_02_green"

	self.registry = {
		id = ID,
		menuText = "Titan|cFF007edd "..L["tooltipTitle"].."|r",
		buttonTextFunction = "TitanPanelTITAN_SOIFTMButton_GetButtonText",
		tooltipTitle = L["tooltipTitle"],
		tooltipTextFunction = "TitanPanelTITAN_SOIFTMButton_GetTooltipText",
		frequency = 2,
		icon = myicon,
		iconWidth = 16,
		category = "Information",
		version = version,
		savedVariables = {
			ShowIcon = 1,
			DisplayOnRightSide = false,
			ShowLabelText = false,
		},
	}
	
	self:SetScript("OnUpdate", function(this, a1)
		elap = elap + a1
		if elap < 1 then return end

		for i = 1, GetCurrencyListSize(), 1 do
			
			name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(i)
			if string.lower(tostring(icon)) == string.lower(mycheck) then
				CurrencyIndex = i
			end
			
		end
		
		name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(CurrencyIndex)

		currencyCount = count
		currencyMaximum = maximum
		
		TitanPanelButton_UpdateButton(ID)
		elap = 0
	end)
		
end

----------------------------------------------
function TitanPanelTITAN_SOIFTMButton_GetButtonText()
----------------------------------------------
	local currencyCountText
	if not currencyCount then
		currencyCountText = TitanUtils_GetHighlightText("0")
	else	
		currencyCountText = TitanUtils_GetHighlightText(string.format("%.0f", currencyCount) .."")
	end
	return L["buttonLabel"], currencyCountText
end

-----------------------------------------------
function TitanPanelTITAN_SOIFTMButton_GetTooltipText() --Thanks to my friend, Eliote
-----------------------------------------------
	local valorAtual = TitanUtils_GetHighlightText(Util_StringComDefault(currencyCount, "0"))
	local valorMaximo = TitanUtils_GetHighlightText(Util_StringComDefault(currencyMaximum, "0"))
	
	return L["tooltipDescription"].."\r\r"..L["tooltipCountLabel"]..valorAtual.." / "..valorMaximo
end

----------------------------------------------------
function TitanPanelRightClickMenu_PrepareTITAN_SOIFTMMenu()
----------------------------------------------------
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[ID].menuText)
	TitanPanelRightClickMenu_AddToggleIcon(ID)
	TitanPanelRightClickMenu_AddToggleLabelText(ID)
	
info = {};
	info.text = ACE["TITAN_CLOCK_MENU_DISPLAY_ON_RIGHT_SIDE"];
	info.func = TitanPanelTITAN_SOIFTMButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	TitanPanelRightClickMenu_AddSpacer();
	TitanPanelRightClickMenu_AddCommand(ACE["TITAN_PANEL_MENU_HIDE"], ID, TITAN_PANEL_MENU_FUNC_HIDE);
end

-----------------------------------------------
function TitanPanelTITAN_SOIFTMButton_ToggleRightSideDisplay() -- Right side display
-----------------------------------------------
	TitanToggleVar(ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end